@@ -137,11 +137,9 @@ def get_gym_max_episode_steps(env_name: str) -> Optional[int]:
 
 def sample_distribution(
     p: np.ndarray,
-    random: Optional[np.random.RandomState] = None,
+    random: np.random.RandomState,
 ) -> int:
     """Samples an integer with probabilities given by p."""
-    if random is None:
-        random = np.random
     return random.choice(np.arange(len(p)), p=p)
 
 
